summaryrefslogtreecommitdiff
path: root/gcc/tree-ssa-loop-ivcanon.c
diff options
context:
space:
mode:
authorrakdver <rakdver@138bc75d-0d04-0410-961f-82ee72b054a4>2007-01-28 17:40:38 +0000
committerrakdver <rakdver@138bc75d-0d04-0410-961f-82ee72b054a4>2007-01-28 17:40:38 +0000
commitbc8bb82538304e37bc9163580496d69daf1c1d36 (patch)
treec62392cb24f6c73aa4b1c6e48f7355a4012a7a9b /gcc/tree-ssa-loop-ivcanon.c
parenta86c75a60e1791a17c23625d466ccee8f9fdc08f (diff)
downloadgcc-bc8bb82538304e37bc9163580496d69daf1c1d36.tar.gz
* tree-ssa-loop-unswitch.c: Include tree-inline.h.
(tree_unswitch_single_loop): Pass eni_size_weights to tree_num_loop_insns. * tree-ssa-loop-manip.c: Include tree-inline.h. (can_unroll_loop_p): Pass eni_size_weights to tree_num_loop_insns. * tree-ssa-loop-ch.c (should_duplicate_loop_header_p): Pass eni_size_weights to estimate_num_insns. * tree.h (init_inline_once): Export. * toplev.c (backend_init): Call init_inline_once. * cgraphunit.c (cgraph_process_new_functions, cgraph_analyze_function): Pass eni_inlining_weights to estimate_num_insns. * ipa-inline.c (compute_inline_parameters): Ditto. * tree-ssa-loop-ivcanon.c (tree_num_loop_insns): Pass weights to estimate_num_insns. (try_unroll_loop_completely): Pass eni_size_weights to tree_num_loop_insns. * tree-eh.c (decide_copy_try_finally): Pass eni_size_weights ot estimate_num_insns. * tree-ssa-loop-prefetch.c: Include tree-inline.h. (loop_prefetch_arrays): Pass eni_time_weights to tree_num_loop_insns. * tree-inline.c (eni_inlining_weights, eni_size_weights, eni_time_weights): New variables. (init_inline_once): Initialize them. (struct eni_data): Mew. (estimate_num_insns_1, estimate_num_insns): Use weights. * tree-inline.h (struct eni_weights_d): New. (eni_inlining_weights, eni_size_weights, eni_time_weights): Declare. (estimate_num_insns): Declaration changed. * cfgloop.h (tree_num_loop_insns): Declaration changed. * Makefile.in (tree-ssa-loop-unswitch.o, tree-ssa-loop-prefetch.o, tree-ssa-loop-manip.o): Add TREE_INLINE_H dependency. * gcc.dg/tree-ssa/loop-23.c: New test. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@121260 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/tree-ssa-loop-ivcanon.c')
-rw-r--r--gcc/tree-ssa-loop-ivcanon.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/tree-ssa-loop-ivcanon.c b/gcc/tree-ssa-loop-ivcanon.c
index fa92a689809..acc8cf30ab5 100644
--- a/gcc/tree-ssa-loop-ivcanon.c
+++ b/gcc/tree-ssa-loop-ivcanon.c
@@ -111,10 +111,10 @@ create_canonical_iv (struct loop *loop, edge exit, tree niter)
update_stmt (cond);
}
/* Computes an estimated number of insns in LOOP. */
unsigned
-tree_num_loop_insns (struct loop *loop)
+tree_num_loop_insns (struct loop *loop, eni_weights *weights)
{
basic_block *body = get_loop_body (loop);
block_stmt_iterator bsi;
@@ -122,7 +122,7 @@ tree_num_loop_insns (struct loop *loop)
for (i = 0; i < loop->num_nodes; i++)
for (bsi = bsi_start (body[i]); !bsi_end_p (bsi); bsi_next (&bsi))
- size += estimate_num_insns (bsi_stmt (bsi));
+ size += estimate_num_insns (bsi_stmt (bsi), weights);
free (body);
return size;
@@ -182,7 +182,7 @@ try_unroll_loop_completely (struct loop *loop,
if (ul == UL_SINGLE_ITER)
return false;
- ninsns = tree_num_loop_insns (loop);
+ ninsns = tree_num_loop_insns (loop, &eni_size_weights);
if (n_unroll * ninsns
> (unsigned) PARAM_VALUE (PARAM_MAX_COMPLETELY_PEELED_INSNS))
@@ -111,10 +111,10 @@ create_canonical_iv (struct loop *loop, edge exit, tree niter)
update_stmt (cond);
}
-/* Computes an estimated number of insns in LOOP. */
+/* Computes an estimated number of insns in LOOP, weighted by WEIGHTS. */
unsigned